summaryrefslogtreecommitdiffstats
path: root/kttsd/plugins/epos/eposconf.h
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/plugins/epos/eposconf.h')
-rw-r--r--kttsd/plugins/epos/eposconf.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kttsd/plugins/epos/eposconf.h b/kttsd/plugins/epos/eposconf.h
index 5c3fbe3..08cb611 100644
--- a/kttsd/plugins/epos/eposconf.h
+++ b/kttsd/plugins/epos/eposconf.h
@@ -25,7 +25,7 @@
#define _EPOSCONF_H_
// Qt includes.
-#include <qstring.h>
+#include <tqstring.h>
// KDE includes.
#include <kconfig.h>
@@ -46,7 +46,7 @@ class EposConf : public PlugInConf {
public:
/** Constructor */
- EposConf( QWidget* parent = 0, const char* name = 0, const QStringList &args = QStringList());
+ EposConf( TQWidget* parent = 0, const char* name = 0, const TQStringList &args = TQStringList());
/** Destructor */
~EposConf();
@@ -58,14 +58,14 @@ class EposConf : public PlugInConf {
* valid settings. NOTE that this is not called after the modules is loaded,
* so you probably want to call this method in the constructor.
*/
- void load(KConfig *config, const QString &configGroup);
+ void load(KConfig *config, const TQString &configGroup);
/** This function gets called when the user wants to save the settings in
* the user interface, updating the config files or wherever the
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok".
*/
- void save(KConfig *config, const QString &configGroup);
+ void save(KConfig *config, const TQString &configGroup);
/** This function is called to set the settings in the module to sensible
* default values. It gets called when hitting the "Default" button. The
@@ -78,7 +78,7 @@ class EposConf : public PlugInConf {
* This function informs the plugin of the desired language to be spoken
* by the plugin. The plugin should attempt to adapt itself to the
* specified language code, choosing sensible defaults if necessary.
* If the passed-in code is QString::null, no specific language has
* been chosen.
* @param lang The desired language code or Null if none.
*
@@ -90,16 +90,16 @@ class EposConf : public PlugInConf {
* not the given country, treat it as though the country
* code were not specified, i.e., adapt to the given language.
*/
- void setDesiredLanguage(const QString &lang);
+ void setDesiredLanguage(const TQString &lang);
/**
* Return fully-specified talker code for the configured plugin. This code
* uniquely identifies the configured instance of the plugin and distinquishes
* one instance from another. If the plugin has not been fully configured,
* i.e., cannot yet synthesize, return QString::null.
* @return Fully-specified talker code.
*/
- QString getTalkerCode();
+ TQString getTalkerCode();
private slots:
void configChanged(){
@@ -118,13 +118,13 @@ class EposConf : public PlugInConf {
/**
* Converts a language code into the language setting passed to Epos synth.
*/
- QString languageCodeToEposLanguage(const QString &languageCode);
+ TQString languageCodeToEposLanguage(const TQString &languageCode);
int percentToSlider(int percentValue);
int sliderToPercent(int sliderValue);
// Language code.
- QString m_languageCode;
+ TQString m_languageCode;
// Configuration widget.
EposConfWidget* m_widget;
@@ -132,10 +132,10 @@ class EposConf : public PlugInConf {
// Epos synthesizer.
EposProc* m_eposProc;
// Synthesized wave file name.
- QString m_waveFile;
+ TQString m_waveFile;
// Progress dialog.
KProgressDialog* m_progressDlg;
// List of displayed codec names.
- QStringList m_codecList;
+ TQStringList m_codecList;
};
#endif // _EPOSCONF_H_
@@ -78,7 +78,7 @@ class EposConf : public PlugInConf {
* by the plugin. The plugin should attempt to adapt itself to the
* specified language code, choosing sensible defaults if necessary.
- * If the passed-in code is QString::null, no specific language has
+ * If the passed-in code is TQString::null, no specific language has
* been chosen.
* @param lang The desired language code or Null if none.
@@ -90,16 +90,16 @@ class EposConf : public PlugInConf {
* uniquely identifies the configured instance of the plugin and distinquishes
* one instance from another. If the plugin has not been fully configured,
- * i.e., cannot yet synthesize, return QString::null.
+ * i.e., cannot yet synthesize, return TQString::null.
* @return Fully-specified talker code.
*/